@@ -157,8 +157,8 @@ static gchar* atom10_parse_content_construct(xmlNodePtr cur) {
 			gchar *tmp;
 
 			g_strchug(g_strchomp(ret));
-
-			if (type != NULL && !strcasecmp(type, "text/plain"))
+			
+			if (type == NULL || !strcasecmp(type, "text"))
 				tmp = atom10_mark_up_text_content(ret);
 			else
 				tmp = g_markup_printf_escaped("<pre>%s</pre>", ret);
