@@ -1,8 +1,8 @@
 /**
  * @file common.c common routines for Liferea
  * 
- * Copyright (C) 2003-2005  Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004,2005  Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2003-2006  Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2006  Nathan J. Conrad <t98502@users.sourceforge.net>
  * Copyright (C) 2004       Karl Soderstrom <ks@xanadunet.net>
  *
  * parts of the RFC822 timezone decoding were taken from the gmime 
@@ -447,10 +447,10 @@ time_t parseISO8601Date(gchar *date) {
 			
 			return t;
 		} else {
-			g_message(_("internal error! time conversion error! mktime failed!\n"));
+			debug0(DEBUG_PARSING, "internal error! time conversion error! mktime failed!\n");
 		}
 	} else {
-		g_message(_("Invalid ISO8601 date format! Ignoring <dc:date> information!\n"));
+		debug0(DEBUG_PARSING, "Invalid ISO8601 date format! Ignoring <dc:date> information!\n");
 	}
 	
 	return 0;
@@ -537,7 +537,7 @@ time_t parseRFC822Date(gchar *date) {
 	if(NULL != (pos = strptime((const char *)date, " %d %b %Y %T", &tm)))
 		success = TRUE;
 	/* non-standard format without seconds and 4 digit year */
-	if(NULL != (pos = strptime((const char *)date, " %d %b %Y %H:%M", &tm)))
+	else if(NULL != (pos = strptime((const char *)date, " %d %b %Y %H:%M", &tm)))
 		success = TRUE;
 	/* non-standard format with seconds and 2 digit year */
 	else if(NULL != (pos = strptime((const char *)date, " %d %b %y %T", &tm)))
@@ -563,8 +563,9 @@ time_t parseRFC822Date(gchar *date) {
 			t2 = mktime(gmtime(&t));
 			t = t - (t2 - t);
 			return t;
-		} else
-			g_warning(_("internal error! time conversion error! mktime failed!\n"));
+		} else {
+			debug0(DEBUG_PARSING, "internal error! time conversion error! mktime failed!\n");
+		}
 	}
 	
 	return 0;
