@@ -53,7 +53,8 @@
 #include "debug.h"
 #include "metadata.h"
 
-#include "ui_feed.h"	/* FIXME: Remove ui_* include from core code */
+#include "ui_enclosure.h"
+#include "ui_feed.h"	
 #include "ui_feedlist.h"
 #include "ui_tray.h"
 #include "ui_htmlview.h"
@@ -315,6 +316,9 @@ void feed_save(feedPtr fp) {
 				ip = iter->data;
 				g_assert(NULL != ip);
 				
+				if(saveMaxCount == CACHE_DISABLE)
+					continue;
+
 				if((saveMaxCount != CACHE_UNLIMITED) &&
 				   (saveCount >= saveMaxCount) &&
 				   (fp->fhp == NULL || fp->fhp->directory == FALSE) &&
@@ -485,8 +489,12 @@ void feed_unload(feedPtr fp) {
 		debug_enter("feed_unload");
 		if(1 == fp->loaded) {
 			if(FST_FEED == feed_get_type(fp)) {
-				debug1(DEBUG_CACHE, "feed_unload (%s)", feed_get_source(fp));
-				feed_clear_item_list(fp);						
+				if(CACHE_DISABLE == fp->cacheLimit) {
+					debug1(DEBUG_CACHE, "not unloading (%s) because cache is disabled", feed_get_source(fp));
+				} else {
+					debug1(DEBUG_CACHE, "unloading (%s)", feed_get_source(fp));
+					feed_clear_item_list(fp);						
+				}
 			} else {
 				debug1(DEBUG_CACHE, "not unloading vfolder (%s)",  feed_get_title(fp));
 			}
@@ -562,7 +570,7 @@ void feed_add_items(feedPtr fp, GList *items) {
 	
 	/* The parser implementations read the items from the
 	   feed from top to bottom. Adding them directly would
-	   mean to reverse there order. */
+	   mean to reverse their order. */
 	iter = g_list_last(items);
 	while(iter != NULL) {
 		feed_add_item(fp, ((itemPtr)iter->data));
@@ -585,7 +593,8 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 	GSList		*old_items;
 	itemPtr		old_ip = NULL;
 	gboolean	found, equal = FALSE;
-	
+	GSList		*iter, *enclosures;
+
 	if(FST_VFOLDER != feed_get_type(fp)) {
 		g_assert(0 != fp->loaded);
 		
@@ -600,7 +609,7 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 			
 			/* try to compare the two items */
 
-			/* trivial case: one item has item the other doesn't -> they can't be equal */
+			/* trivial case: one item has id the other doesn't -> they can't be equal */
 			if(((item_get_id(old_ip) == NULL) && (item_get_id(new_ip) != NULL)) ||
 			   ((item_get_id(old_ip) != NULL) && (item_get_id(new_ip) == NULL))) {	
 				/* cannot be equal (different ids) so compare to 
@@ -657,6 +666,19 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 				new_ip->nr = ++(fp->lastItemNr);
 				fp->needsCacheSave = TRUE;
 			}
+
+			/* If a new item has enclosures and auto downloading
+			   is enabled we start the download. Enclosures added
+			   by updated items are not supported. */
+			if((TRUE == fp->encAutoDownload) &&
+			   (TRUE == item_get_new_status(new_ip))) {
+				iter = enclosures = metadata_list_get(new_ip->metadata, "enclosure");
+				while(NULL != iter) {
+					debug1(DEBUG_UPDATE, "download enclosure (%s)", (gchar *)iter->data);
+					ui_enclosure_save(NULL, (gchar*)iter->data, NULL);
+					iter = g_slist_next(iter);
+				}
+			}
 		
 			if(FALSE == item_get_read_status(new_ip))
 				feed_increase_unread_counter(fp);
