@@ -46,6 +46,7 @@ static GHashTable 	*iterhash = NULL;	/* hash table used for fast item->tree iter
 
 gint			itemlist_loading;	/* freaky workaround for item list focussing problem */
 
+extern nodePtr		displayed_node;
 itemPtr			displayed_item = NULL;
 
 #define	TIMESTRLEN	256
@@ -400,18 +401,15 @@ void ui_itemlist_prefocus(void) {
 void ui_itemlist_display(void) {
 	GtkTreeStore	*itemstore = ui_itemlist_get_tree_store();
 	GtkTreeIter	iter;
-	nodePtr		np;
 	itemPtr		ip;
 	gchar		*buffer = NULL;
 	gboolean	valid;
 	gchar		*tmp = NULL;
 	const gchar	*base = NULL;
 	
-	np = ui_feedlist_get_selected();
-	
-	if(np != NULL) {
-		if(FST_FOLDER != np->type)
-			base = feed_get_html_url((feedPtr)np);
+	if(displayed_node) {
+		if(FST_FOLDER != displayed_node->type)
+			base = feed_get_html_url((feedPtr)displayed_node);
 			
 		if(TRUE == ui_itemlist_get_two_pane_mode()) {
 			/* two pane mode */
@@ -442,13 +440,13 @@ void ui_itemlist_display(void) {
 		} else {
 			/* three pane mode */
 			
-			/* The feed info is displayed only if there is not a currently displayed item */
-			if(displayed_item == NULL) {			
+			/* The feed info is displayed only if there is no currently displayed item */
+			if(displayed_item == NULL) {
 				/* display feed info */
 				ui_htmlview_start_output(&buffer, base, TRUE);
-				if((FST_FEED == np->type) || 
-				   (FST_VFOLDER == np->type)) {
-					tmp = feed_render((feedPtr)np);
+				if((FST_FEED == displayed_node->type) || 
+				   (FST_VFOLDER == displayed_node->type)) {
+					tmp = feed_render((feedPtr)displayed_node);
 					addToHTMLBufferFast(&buffer, tmp);
 					g_free(tmp);
 				}
@@ -465,12 +463,12 @@ void ui_itemlist_display(void) {
 	}
 	
 	if(buffer) {
-		if((np != NULL) &&
-		   (FST_FEED == np->type) &&
-		   ((feedPtr)np)->htmlUrl != NULL &&
-		   ((feedPtr)np)->htmlUrl[0] != '|' &&
-		   strstr(((feedPtr)np)->htmlUrl, "://") != NULL)
-			ui_htmlview_write(ui_mainwindow_get_active_htmlview(), buffer, ((feedPtr)np)->htmlUrl);
+		if((displayed_node != NULL) &&
+		   (FST_FEED == displayed_node->type) &&
+		   ((feedPtr)displayed_node)->htmlUrl != NULL &&
+		   ((feedPtr)displayed_node)->htmlUrl[0] != '|' &&
+		   strstr(((feedPtr)displayed_node)->htmlUrl, "://") != NULL)
+			ui_htmlview_write(ui_mainwindow_get_active_htmlview(), buffer, ((feedPtr)displayed_node)->htmlUrl);
 		else
 			ui_htmlview_write(ui_mainwindow_get_active_htmlview(), buffer, NULL);
 		g_free(buffer);
