@@ -1,8 +1,8 @@
 /**
  * @file ui_mainwindow.c some functions concerning the main window 
  *
- * Copyright (C) 2004-2005 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2004-2006 Lars Lindner <lars.lindner@gmx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -346,8 +346,13 @@ void ui_mainwindow_finish(GtkWidget *window) {
 	itemlist_set_two_pane_mode(TRUE);
 	
 	/* set zooming properties */	
-	zoom = getNumericConfValue(LAST_ZOOMLEVEL)/100.;
-	ui_htmlview_set_zoom(htmlview, zoom);
+	zoom = getNumericConfValue(LAST_ZOOMLEVEL);
+
+	if(0 == zoom) {	/* workaround for scheme problem with the last releases */
+		zoom = 100;
+		setNumericConfValue(LAST_ZOOMLEVEL, 100);
+	}
+	ui_htmlview_set_zoom(htmlview, zoom/100.);
 	
 	/* create welcome text */
 	ui_htmlview_start_output(&buffer, NULL, FALSE);
