@@ -145,9 +145,14 @@ void download_process(struct request *request) {
 		}
 	} else {
 		gchar *filename = request->source;
-		if (!strncmp(request->source, "file://",7))
-			filename = &(filename[7]);
+		gchar *anchor;
+
+		if(!strncmp(filename, "file://",7))
+			filename += 7;
 		
+		if(anchor = strchr(filename, '#'))
+			*anchor = 0;	 /* strip anchors from filenames */
+
 		if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
 			/* we have a file... */
 			if((!g_file_get_contents(filename, &(request->data), &(request->size), NULL)) || (request->data[0] == '\0')) {
@@ -160,7 +165,7 @@ void download_process(struct request *request) {
 		} else {
 			ui_mainwindow_set_status_bar(_("Error: There is no file \"%s\""), filename);
 			request->httpstatus = 404;	/* FIXME: maybe setting request->returncode would be better */
-		}		
+		}
 	}
 
 	/* And execute the postfilter */
