@@ -219,7 +219,9 @@ static void vfolder_apply_rules(nodePtr np, gpointer userdata) {
 	GSList		*items;
 
 	/* do not search in vfolders */
-	g_return_if_fail(FST_VFOLDER != feed_get_type(fp));
+	if (FST_VFOLDER == feed_get_type(fp))
+		return; /* Or maybe ui_feedlist_do_for_all should be changed
+				   to not treat vfolders as a type of feed? */
 
 	debug_enter("vfolder_apply_rules");
 
